Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-1-4]: src/distrib/utils/sysinst/arch/mac68k pull up rev(s) 1.6-1....



details:   https://anonhg.NetBSD.org/src/rev/819c4237abb5
branches:  netbsd-1-4
changeset: 468994:819c4237abb5
user:      cgd <cgd%NetBSD.org@localhost>
date:      Thu Jun 24 22:51:39 1999 +0000

description:
pull up rev(s) 1.6-1.8 from trunk. (cgd)

diffstat:

 distrib/utils/sysinst/arch/mac68k/md.c |  19 ++++++++++---------
 1 files changed, 10 insertions(+), 9 deletions(-)

diffs (82 lines):

diff -r f41fc623c9a4 -r 819c4237abb5 distrib/utils/sysinst/arch/mac68k/md.c
--- a/distrib/utils/sysinst/arch/mac68k/md.c    Thu Jun 24 22:51:32 1999 +0000
+++ b/distrib/utils/sysinst/arch/mac68k/md.c    Thu Jun 24 22:51:39 1999 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: md.c,v 1.2.2.1 1999/04/19 15:19:29 perry Exp $ */
+/*     $NetBSD: md.c,v 1.2.2.2 1999/06/24 22:51:39 cgd Exp $ */
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -16,7 +16,7 @@
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
  *    must display the following acknowledgement:
- *      This product includes software develooped for the NetBSD Project by
+ *      This product includes software developed for the NetBSD Project by
  *      Piermont Information Systems Inc.
  * 4. The name of Piermont Information Systems Inc. may not be used to endorse
  *    or promote products derived from this software without specific prior
@@ -417,7 +417,7 @@
 }
 
 /*
  * check for any anomolies on the requested setup
  */
 int
 check_for_errors()
@@ -439,7 +439,7 @@
 }
 
 /*
  * check for and report anomolies on the requested setup
  */
 void
 report_errors()
@@ -480,7 +480,7 @@
        }
     }
     if (!errs)
-       msg_printf_add ("** No errors or anomolies found in disk setup.\n");
+       msg_printf_add ("** No errors or anomalies found in disk setup.\n");
     return;
 }
 
@@ -646,7 +646,7 @@
      */
     if ((fd = open(devname, O_WRONLY, 0)) < 0) {
        endwin();
-       fprintf(stderr, "Can't open %s to re-write the Disk Map\n", devname);
+       fprintf(stderr, "Can't open %s to rewrite the Disk Map\n", devname);
        exit (1);
     }
     /*
@@ -671,7 +671,7 @@
     }
     if (lseek (fd, (off_t)1 * bsize, SEEK_SET) < 0) {
        endwin();
-       fprintf (stderr, "Can't position disk to re-write Disk Map\n");
+       fprintf (stderr, "Can't position disk to rewrite Disk Map\n");
        close (fd);
        exit (1);
     }
@@ -732,7 +732,7 @@
         * Scan for any problems and report them before continuing.
         *  The user can abort installation and we'll take them back
         *  to the main menu; continue ignoring the warnings, or
-        *  ask to re-edit the Disk Partition Map.
+        *  ask to reedit the Disk Partition Map.
         */
        while (1) {
            if (check_for_errors()) {
@@ -856,7 +856,8 @@
        endwin();
        md_copy_filesystem ();
        md_post_newfs();
-       puts (CL);
+       puts(CL);               /* XXX */
+       wclear(stdscr);
        wrefresh(stdscr);
        return 1;
 }
@@ -417,7 +417,7 @@
 
 /*
- * check for any anomolies on the requested setup
+ * check for any anomalies on the requested setup
  */
 int
@@ -439,7 +439,7 @@
 
 /*
- * check for and report anomolies on the requested setup
+ * check for and report anomalies on the requested setup
  */
 void



Home | Main Index | Thread Index | Old Index